@@ -1511,6 +1511,27 @@ class Sequence(Generic[T], Iterable[T]):
         """
         return list(self)
     
+    def let(self, block: Callable[[Sequence[T]], R]) -> R:
+        """
+         Calls the specified function [block] with `self` value as its argument and returns its result.
+            
+         Example 1:
+        >>> it(['a', 'b', 'c']).let(lambda x: x.map(lambda y: y + '!'))
+        ['a!', 'b!', 'c!']
+        """
+        return block(self)
+    
+    def also(self, block: Callable[[Sequence[T]], R]) -> R:
+        """
+         Calls the specified function [block] with `self` value as its argument and returns `self` value.
+            
+         Example 1:
+        >>> it(['a', 'b', 'c']).also(lambda x: x.map(lambda y: y + '!'))
+        ['a', 'b', 'c']
+        """
+        block(self)
+        return self
+    
     @property
     def len(self) -> int:
         if not isinstance(self._iter, Sequence):
